@@ -236,7 +236,8 @@ class SFREAD:
                     return self.getobject(rel)
         return None
 
-    def getobject(self, obj, cal=False, nbeg=None, nend=None):
+
+    def getobject(self, obj, cal=False, nbeg=None, nend=None, tbeg=None, tend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
         """
@@ -246,7 +247,8 @@ class SFREAD:
         if obj not in self.sfh.keys():
             logger.error('Signal %s:%s not found for #%d', self.diag, obj, self.shot)
             return None
-# Don't uncomment the following lines, to allow 1 cal and 1 uncal reading
+
+# Keep commented, to allow 1 cal and 1 uncal reading
 #        if obj in self.cache.keys(): 
 #            return cache[obj]
 
@@ -255,6 +257,22 @@ class SFREAD:
             logger.error('Status of SF object %s is %d' %(obj, sfo.status))
             return None
         otyp = sfo.obj_type
+
+        if tbeg is not None or tend is not None:
+            if tend is None:
+                tend = 10.
+            if tbeg is None:
+                tbeg = 0.
+            tb = self.gettimebase(obj)
+            jt_beg, jt_end = tb.searchsorted((tbeg, tend))
+            if otyp in (Signal, TimeBase) or self.time_last(obj):
+                return self.getobject(obj, nbeg=jt_beg, nend=jt_end)
+            elif self.time_first(obj):
+                return self.getobject(obj)[jt_beg: jt_end]
+            else:
+                logger.error('tbeg, tend keywords supported only when time is first or last dim')
+                return None
+
         if otyp in (SignalGroup, Signal):
             shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
         elif otyp == TimeBase:
@@ -570,28 +588,35 @@ class SFREAD:
         return ts06
 
 
-    def time_first(self, obj):
+    def time_dim(self, obj):
         """
-        Tells whether a SigGroup has time as first coordinate
-        by comparing with the size of the related TBase
+        Tells which SigGroup dimension is a time dimension
         """
 
         obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp != SignalGroup:
-            return False # Objects other than sig, sgr, tbase
+            return None # Objects other than sig, sgr, tbase
 
         for rel in sfo.relations:
             if self.sfh[rel].obj_type == TimeBase:
-                shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
+                shape_arr = sfo.index[::-1][:sfo.num_dims]
                 nt = self.sfh[rel].n_steps
-                if shape_arr[0] != nt:
-                    return False
-                for jdim in range(1, sfo.num_dims):
-                    if shape_arr[jdim] == nt:
-                        return False # Two dimension are
-                return True # No other dim's size matches by chance
+                if shape_arr.count(nt) == 1:
+                    return shape_arr.index(nt)
+                else:
+                    return None
+        return None # If there is no timebase among the relations
+
+
+    def time_first(self, obj):
+        """
+        Tells whether a SigGroup has time as first coordinate
+        by comparing with the size of the related TBase
+        """
+
+        return (self.time_dim(obj) == 0)
 
 
     def time_last(self, obj):
@@ -602,17 +627,5 @@ class SFREAD:
 
         obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
-        otyp = sfo.obj_type
-        if otyp != SignalGroup:
-            return False # Objects other than sig, sgr, tbase
-
-        for rel in sfo.relations:
-            if self.sfh[rel].obj_type == TimeBase:
-                shape_arr = np.array(sfo.index[::-1][:sfo.num_dims])
-                nt = self.sfh[rel].n_steps
-                if shape_arr[-1] != nt:
-                    return False
-                for jdim in range(sfo.num_dims-1):
-                    if shape_arr[jdim] == nt:
-                        return False # Two dimension are
-                return True # No other dim's size matches by chance
+        
+        return (self.time_dim(obj) == sfo.num_dims-1)
