@@ -298,7 +298,7 @@ class WW:
         return True
 
 
-    def SetAreabase(self, areaname, data):
+    def SetAreabase(self, areaname, data, tim_axis=0):
         """Stores 'data'-array of a given Areabase named 'areaname'
         to the target shotfile
         """
@@ -314,15 +314,18 @@ class WW:
             data = np.array(data, dtype=sfdics.fmt2np[dfmt])
             areaname = str_byt.to_byt(areaname)     
             sizes = (ct.c_uint32 * 3)()
-            for jsiz in range(data.ndim):
-                sizes[jsiz] = data.shape[jsiz]
-            if data.ndim > 1:
-                nt = data.shape[0]
-                if nt > 1:
-                    sizes[0] = sizes[1]
-                    sizes[1] = sizes[2]
-            else:
+            if tim_axis is not None and tim_axis != 0:
+                logger.error('tim_axis can be only None or 0, not %d', tim_axis)
+                return
+            if tim_axis is None or data.ndim == 1:
                 nt = 1
+            else:
+                nt = data.shape[tim_axis]
+                jsiz = 0
+                for jdim in range(data.ndim):
+                    if jdim != tim_axis:
+                        sizes[jsiz] = data.shape[jdim]
+                    jsiz += 1
             logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *sizes[:3])
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
